bayespy.inference.vmp.nodes.gamma.GammaMoments.get_converter
============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gamma

.. automethod:: GammaMoments.get_converter